import {Component, OnInit} from '@angular/core';
import {ActivatedRoute} from "@angular/router";
import {ConfigurationService} from "../env/configuration.service";
import {HttpClient, HttpHeaders} from "@angular/common/http";
import {map} from "rxjs/operators";
import {Observable} from "rxjs";
import {FormControl, FormGroup} from "@angular/forms";

@Component({
  selector: 'app-fileeditor',
  templateUrl: './fileeditor.component.html',
  styleUrls: ['./fileeditor.component.scss']
})
export class FileeditorComponent implements OnInit {

  origin: string;
  id: string;
  type: string;
  name: string;
  changed: boolean = false;
  content: Observable<string>;
  displayedUrl: string;

  formGroup: FormGroup;

  feedback: string = '';

  constructor(
    private route: ActivatedRoute,
    private configService: ConfigurationService,
    private http: HttpClient) {
    this.formGroup = new FormGroup({
      content: new FormControl()
    });
  }

  ngOnInit() {
    this.origin = this.route.snapshot.paramMap.get('origin');
    this.id = this.route.snapshot.paramMap.get('id');
    this.type = this.route.snapshot.paramMap.get('type');
    this.name = this.route.snapshot.paramMap.get('name');
    this.getContent();
  }

  getContent(): void {
    let url = "";
    switch (this.origin) {
      case "specs":
        url = "job/specs/" + this.id + "/files/" + this.type + "/" + this.name;
        break;
      case "type":
        url = "product/types/" + this.id + "/" + this.name;
        break;
      case "product":
        url = "product/byId/" + this.id + "/" + this.name;
        break;
      case "file_template":
        url = "job/queues/" + this.id + "/workflow/files/" + this.name;
        break;
      case "file_documentation":
        url = "job/queues/" + this.id + "/workflow/files/" + this.name + "/documentation";
        break;
      case "tile":
        url = "minitiles/" + this.id + "/" + this.name;
        break;
    }
    if (url.length > 0) {
      this.displayedUrl = url;
      this.content = this.http.get(this.configService.config.url + '/services/' + url, {
        observe: "response",
        responseType: "text"
      }).pipe(map(response => {
        console.log('get file: ', response);
        this.formGroup.get('content').setValue(response.body);
        return response.body;
      }));
    }
  }

  onSubmit() {
    this.feedback = 'Saving...';
    if (this.displayedUrl !== '') {
      let headers = new HttpHeaders();

      switch (this.type) {
        case "json":
          headers = headers.append('Content-Type', "application/json");
          break;
        case "xml":
          headers = headers.append('Content-Type', "text/xml");
          break;
        default:
          headers = headers.append('Content-Type', "text/plain");
      }

      this.http.put(this.configService.config.url + '/services/' + this.displayedUrl, this.formGroup.get('content').value, {
        observe: "response", responseType: "text", headers: headers
      }).subscribe(response => {
        console.log('put file: ', response);
        this.feedback = 'Save Successful';
        return response.body;
      });

    } else {
      this.feedback = 'No saving target';
    }
  }

}
